pub struct ContentRecord {
pub content_reference_key: String,
pub content_metadata: Option<Box<ContentMetadata>>,
pub content_document: Option<Box<ContentDocument>>,
}Expand description
ContentRecord : A content document with additional information for content management.
Fields
content_reference_key: StringA unique reference key for the A+ Content document. A content reference key cannot form a permalink and may change in the future. A content reference key is not guaranteed to match any A+ content identifier.
content_metadata: Option<Box<ContentMetadata>>content_document: Option<Box<ContentDocument>>Implementations
sourceimpl ContentRecord
impl ContentRecord
sourcepub fn new(content_reference_key: String) -> ContentRecord
pub fn new(content_reference_key: String) -> ContentRecord
A content document with additional information for content management.